@@ -90,8 +90,19 @@ class iRODSDataObject(object):
         return self.manager.open(self.path, mode, finalize_on_close = finalize_on_close, **options)
 
     def chksum(self, **options):
+        """
+        See: https://github.com/irods/irods/blob/4-2-stable/lib/api/include/dataObjChksum.h
+        for a list of applicable irods.keywords options.
+
+        NB options dict may also include a default-constructed RErrorStack object under the key r_error.
+        If passed, this object can receive a list of warnings, one for each existing replica lacking a
+        checksum.  (Relevant only in combination with VERIFY_CHKSUM_KW).
+        """
         return self.manager.chksum(self.path, **options)
 
+    def trim(self, **options):
+        self.manager.trim(self.path, **options)
+
     def unlink(self, force=False, **options):
         self.manager.unlink(self.path, force, **options)
 
